@@ -573,7 +573,7 @@ class EFC(object):
 
         return (self.df)
 
-    def transform(self, state=None, line=None, cols=None):
+    def transform(self, state=None, line=None, cols=None, regions=None):
         """
         The transformation method of the data.  
         Arguments activate the transformation, otherwise they are not performed.
@@ -612,6 +612,16 @@ class EFC(object):
                 tmp_f = tmp >> select(cols)
                 tmpdf = tmp_f
         
+        # add the regions info
+        if regions:
+            r = datasets.region_xwalk()
+            r = r >> select(['fips','name','ipeds_region', 'postal code'])
+            r = r.rename(columns={"fips": "efcstate", "postal code":"abbrev"})
+            r['efcstate'] = r['efcstate'].astype('float64')
+            tmp = tmpdf
+            tmp_f = pd.merge(left=tmp, right=r, on="efcstate", how="left")
+            tmpdf = tmp_f
+        
         # return the data
         self.df = tmpdf
 
